==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/UpdateHistoryFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class UpdateHistoryFluentImpl<A extends io.fabric8.openshift.api.model.UpdateHistoryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.UpdateHistoryFluent<A>{
  public UpdateHistoryFluentImpl() {
  }
  public UpdateHistoryFluentImpl(io.fabric8.openshift.api.model.UpdateHistory instance) {
    this.withCompletionTime(instance.getCompletionTime()); 
    this.withImage(instance.getImage()); 
    this.withStartedTime(instance.getStartedTime()); 
    this.withState(instance.getState()); 
    this.withVerified(instance.getVerified()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String completionTime;
  private java.lang.String image;
  private java.lang.String startedTime;
  private java.lang.String state;
  private java.lang.Boolean verified;
  private java.lang.String version;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCompletionTime() {
    return this.completionTime;
  }
  public A withCompletionTime(java.lang.String completionTime) {
    this.completionTime=completionTime; return (A) this;
  }
  public java.lang.Boolean hasCompletionTime() {
    return this.completionTime != null;
  }
  
  /**
   * Method is deprecated. use withCompletionTime instead.
   */
  @java.lang.Deprecated
  public A withNewCompletionTime(java.lang.String arg0) {
    return (A)withCompletionTime(new String(arg0));
  }
  public java.lang.String getImage() {
    return this.image;
  }
  public A withImage(java.lang.String image) {
    this.image=image; return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0) {
    return (A)withImage(new String(arg0));
  }
  public java.lang.String getStartedTime() {
    return this.startedTime;
  }
  public A withStartedTime(java.lang.String startedTime) {
    this.startedTime=startedTime; return (A) this;
  }
  public java.lang.Boolean hasStartedTime() {
    return this.startedTime != null;
  }
  
  /**
   * Method is deprecated. use withStartedTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartedTime(java.lang.String arg0) {
    return (A)withStartedTime(new String(arg0));
  }
  public java.lang.String getState() {
    return this.state;
  }
  public A withState(java.lang.String state) {
    this.state=state; return (A) this;
  }
  public java.lang.Boolean hasState() {
    return this.state != null;
  }
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0) {
    return (A)withState(new String(arg0));
  }
  public java.lang.Boolean getVerified() {
    return this.verified;
  }
  public A withVerified(java.lang.Boolean verified) {
    this.verified=verified; return (A) this;
  }
  public java.lang.Boolean hasVerified() {
    return this.verified != null;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public A withVersion(java.lang.String version) {
    this.version=version; return (A) this;
  }
  public java.lang.Boolean hasVersion() {
    return this.version != null;
  }
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0) {
    return (A)withVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpdateHistoryFluentImpl that = (UpdateHistoryFluentImpl) o;
    if (completionTime != null ? !completionTime.equals(that.completionTime) :that.completionTime != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (startedTime != null ? !startedTime.equals(that.startedTime) :that.startedTime != null) return false;
    if (state != null ? !state.equals(that.state) :that.state != null) return false;
    if (verified != null ? !verified.equals(that.verified) :that.verified != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(completionTime,  image,  startedTime,  state,  verified,  version,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/UpdateHistoryFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class UpdateHistoryFluentImpl<A extends io.fabric8.openshift.api.model.UpdateHistoryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.UpdateHistoryFluent<A>{
  public UpdateHistoryFluentImpl() {
  }
  public UpdateHistoryFluentImpl(io.fabric8.openshift.api.model.UpdateHistory instance) {
    this.withAcceptedRisks(instance.getAcceptedRisks()); 
    this.withCompletionTime(instance.getCompletionTime()); 
    this.withImage(instance.getImage()); 
    this.withStartedTime(instance.getStartedTime()); 
    this.withState(instance.getState()); 
    this.withVerified(instance.getVerified()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String acceptedRisks;
  private java.lang.String completionTime;
  private java.lang.String image;
  private java.lang.String startedTime;
  private java.lang.String state;
  private java.lang.Boolean verified;
  private java.lang.String version;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAcceptedRisks() {
    return this.acceptedRisks;
  }
  public A withAcceptedRisks(java.lang.String acceptedRisks) {
    this.acceptedRisks=acceptedRisks; return (A) this;
  }
  public java.lang.Boolean hasAcceptedRisks() {
    return this.acceptedRisks != null;
  }
  
  /**
   * Method is deprecated. use withAcceptedRisks instead.
   */
  @java.lang.Deprecated
  public A withNewAcceptedRisks(java.lang.String arg0) {
    return (A)withAcceptedRisks(new String(arg0));
  }
  public java.lang.String getCompletionTime() {
    return this.completionTime;
  }
  public A withCompletionTime(java.lang.String completionTime) {
    this.completionTime=completionTime; return (A) this;
  }
  public java.lang.Boolean hasCompletionTime() {
    return this.completionTime != null;
  }
  
  /**
   * Method is deprecated. use withCompletionTime instead.
   */
  @java.lang.Deprecated
  public A withNewCompletionTime(java.lang.String arg0) {
    return (A)withCompletionTime(new String(arg0));
  }
  public java.lang.String getImage() {
    return this.image;
  }
  public A withImage(java.lang.String image) {
    this.image=image; return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0) {
    return (A)withImage(new String(arg0));
  }
  public java.lang.String getStartedTime() {
    return this.startedTime;
  }
  public A withStartedTime(java.lang.String startedTime) {
    this.startedTime=startedTime; return (A) this;
  }
  public java.lang.Boolean hasStartedTime() {
    return this.startedTime != null;
  }
  
  /**
   * Method is deprecated. use withStartedTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartedTime(java.lang.String arg0) {
    return (A)withStartedTime(new String(arg0));
  }
  public java.lang.String getState() {
    return this.state;
  }
  public A withState(java.lang.String state) {
    this.state=state; return (A) this;
  }
  public java.lang.Boolean hasState() {
    return this.state != null;
  }
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0) {
    return (A)withState(new String(arg0));
  }
  public java.lang.Boolean getVerified() {
    return this.verified;
  }
  public A withVerified(java.lang.Boolean verified) {
    this.verified=verified; return (A) this;
  }
  public java.lang.Boolean hasVerified() {
    return this.verified != null;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public A withVersion(java.lang.String version) {
    this.version=version; return (A) this;
  }
  public java.lang.Boolean hasVersion() {
    return this.version != null;
  }
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0) {
    return (A)withVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpdateHistoryFluentImpl that = (UpdateHistoryFluentImpl) o;
    if (acceptedRisks != null ? !acceptedRisks.equals(that.acceptedRisks) :that.acceptedRisks != null) return false;
    if (completionTime != null ? !completionTime.equals(that.completionTime) :that.completionTime != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (startedTime != null ? !startedTime.equals(that.startedTime) :that.startedTime != null) return false;
    if (state != null ? !state.equals(that.state) :that.state != null) return false;
    if (verified != null ? !verified.equals(that.verified) :that.verified != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acceptedRisks,  completionTime,  image,  startedTime,  state,  verified,  version,  additionalProperties,  super.hashCode());
  }
  
}
